@@ -27,5 +27,5 @@ elif sys.platform == 'win32':
 setup(
     name="superdoodle",
     setup_requires=["py2app"],
-    **{buildstyle : ['superdoodle.py']},
+    **{buildstyle : ['superdoodle.py']}
 )
