@@ -27,7 +27,7 @@ typedef void (*Py_FinalizePtr)(void);
 typedef PyObject *(*PySys_GetObjectPtr)(const char *);
 typedef int *(*PySys_SetArgvPtr)(int argc, char **argv);
 typedef PyObject *(*PyObject_GetAttrStringPtr)(PyObject *, const char *);
-typedef wchar_t* (*_Py_DecodeUTF8_surrogateescapePtr)(const char *s, ssize_t size);
+typedef wchar_t* (*_Py_DecodeUTF8_surrogateescapePtr)(const char *s, ssize_t size, ssize_t* outsize);
 
 
 typedef CFTypeRef id;
@@ -894,6 +894,15 @@ static int py2app_main(int argc, char * const *argv, char * const *envp) {
      */
     setenv("PYTHONDONTWRITEBYTECODE", "1", 1);
 
+#ifndef PY2APP_SECONDARY
+    /*
+     * Force stdout/stderr to be unbuffered, needed when using the ASL
+     * output redirection because Python 3's IO library won't use
+     * line buffering with that.
+     */
+    setenv("PYTHONUNBUFFERED", "1", 1);
+#endif
+
 
     if (!py2app_getApplicationName()) return report_error(ERR_NONAME);
     pyLocations = (CFArrayRef)py2app_getKey("PyRuntimeLocations");
@@ -1028,12 +1037,12 @@ static int py2app_main(int argc, char * const *argv, char * const *envp) {
     if (isPy3K) {
        int i;
 
-       argv_new = alloca((argc+1) * sizeof(wchar_t));
+       argv_new = alloca((argc+1) * sizeof(wchar_t*));
        argv_new[argc] = NULL;
-       argv_new[0] = (char*)py2app__Py_DecodeUTF8_surrogateescape(c_mainScript, strlen(c_mainScript));
+       argv_new[0] = (char*)py2app__Py_DecodeUTF8_surrogateescape(c_mainScript, strlen(c_mainScript), NULL);
 
        for (i = 1; i < argc; i++) {
-	  argv_new[i] = (char*)py2app__Py_DecodeUTF8_surrogateescape(argv[i], strlen(argv[i]));
+	  argv_new[i] = (char*)py2app__Py_DecodeUTF8_surrogateescape(argv[i], strlen(argv[i]), NULL);
        }
 
     } else {
@@ -1057,6 +1066,7 @@ static int py2app_main(int argc, char * const *argv, char * const *envp) {
     return rval;
 }
 
+#ifdef REDIRECT_ASL
 void
 setup_asl(const char* appname)
 {
@@ -1137,6 +1147,7 @@ setup_asl(const char* appname)
 	do_asl_log_descriptor(cl, msg, 4 /* ASL_LEVEL_NOTICE */, 1, 2 /* ASL_LOG_DESCRIPTOR_WRITE */);
 	do_asl_log_descriptor(cl, msg, 4 /* ASL_LEVEL_NOTICE */, 2, 2 /* ASL_LOG_DESCRIPTOR_WRITE */);
 }
+#endif
 
 #ifndef PY2APP_SECONDARY
 static int
@@ -1183,15 +1194,16 @@ main(int argc, char * const *argv, char * const *envp)
 	} else {
 	    /* OSX 10.9 or later */
             if (fstat(1, &st) != -1) {
-	        if (!S_ISCHR(st.st_mode) ||
-	            major(st.st_dev) != 3 ||
-     	            minor(st.st_dev) != 2) {
-
-    	    	        /* We appear to be launched from the
-			 * command-line after all.
-		         */
-		        is_app_bundle = st.st_dev;
-	        }
+		is_app_bundle = 0;
+		if (S_ISCHR(st.st_mode)) {
+		    if (major(st.st_dev) == 3 && minor(st.st_dev) == 2) {
+			/* devnull */
+		        is_app_bundle = 1;
+		    } else if (major(st.st_dev) != 4 && major(st.st_dev) != 5) {
+			/* not pty or tty */
+		        is_app_bundle = 1;
+		    }
+		}
             }
         }
     }
@@ -1208,7 +1220,9 @@ main(int argc, char * const *argv, char * const *envp)
 	    bname++;
         }
 
+#ifdef REDIRECT_ASL
         setup_asl(bname);
+#endif /* REDIRECT_ASL */
     }
 #endif /* !PY2APP_SECONDARY */
 
