@@ -1,7 +1,8 @@
 def _setup_ctypes():
     from ctypes.macholib import dyld
     import os
-    frameworks = os.path.join(os.environ['RESOURCEPATH'], '..', 'Frameworks')
+
+    frameworks = os.path.join(os.environ["RESOURCEPATH"], "..", "Frameworks")
     dyld.DEFAULT_FRAMEWORK_FALLBACK.insert(0, frameworks)
     dyld.DEFAULT_LIBRARY_FALLBACK.insert(0, frameworks)
 
