@@ -5,6 +5,19 @@ import re
 import sys
 
 gPreBuildVariants = [
+    {
+        "name": "main-universal2",
+        "target": "10.9",
+        "cflags": "-g -arch arm64 -arch x86_64",
+        "cc": "/usr/bin/clang",
+    },
+    {
+        "name": "main-arm64",
+        "target": "10.16",
+        "cflags": "-g -arch arm64",
+        "cc": "/usr/bin/clang",
+    },
+
     {
         "name": "main-universal",
         "target": "10.5",
