@@ -9,9 +9,10 @@ The problem with SIP is that all inter-module depedencies (for example from
 PyQt4.Qt to PyQt4.QtCore) are handled in C code and therefore cannot be
 detected by the python code in py2app).
 """
-import sys
 import glob
 import os
+import sys
+
 import pkg_resources
 
 
@@ -34,7 +35,7 @@ class Sip(object):
             cfg = pyqtconfig.Configuration()
             qtdir = cfg.qt_lib_dir
             sipdir = os.path.dirname(cfg.pyqt_mod_dir)
-            self.plugin_dir = os.path.join(cfg.qt_dir, 'plugins')
+            self.plugin_dir = os.path.join(cfg.qt_dir, "plugins")
         except ImportError:
             from PyQt5.QtCore import QLibraryInfo
 
@@ -48,11 +49,11 @@ class Sip(object):
             raise ImportError
 
         # Qt is GHETTO!
-        dyld_library_path = os.environ.get('DYLD_LIBRARY_PATH', '').split(':')
+        dyld_library_path = os.environ.get("DYLD_LIBRARY_PATH", "").split(":")
 
         if qtdir not in dyld_library_path:
             dyld_library_path.insert(0, qtdir)
-            os.environ['DYLD_LIBRARY_PATH'] = ':'.join(dyld_library_path)
+            os.environ["DYLD_LIBRARY_PATH"] = ":".join(dyld_library_path)
 
         self.packages = set()
 
@@ -60,13 +61,12 @@ class Sip(object):
             fullpath = os.path.join(sipdir, fn)
             if os.path.isdir(fullpath):
                 self.packages.add(fn)
-                if fn in ('PyQt4', 'PyQt5'):
+                if fn in ("PyQt4", "PyQt5"):
                     # PyQt4 and later has a nested structure, also import
                     # subpackage to ensure everything get seen.
                     for sub in os.listdir(fullpath):
                         if ".py" not in sub:
-                            self.packages.add('%s.%s' % (
-                                fn, sub.replace(".so", "")))
+                            self.packages.add("%s.%s" % (fn, sub.replace(".so", "")))
 
         print("sip: packages: %s" % (self.packages,))
 
@@ -78,22 +78,22 @@ class Sip(object):
         except ImportError:
             return None
 
-        if 'PyQt4.uic' in packages:
+        if "PyQt4.uic" in packages:
             # PyQt4.uic contains subpackages with python 2 and python 3
             # support. Exclude the variant that won't be ussed, this avoids
             # compilation errors on Python 2 (because some of the Python 3
             # code is not valid Python 2 code)
             if sys.version_info[0] == 2:
-                ref = 'PyQt4.uic.port_v3'
+                ref = "PyQt4.uic.port_v3"
             else:
-                ref = 'PyQt4.uic.port_v2'
+                ref = "PyQt4.uic.port_v2"
 
-        if 'PyQt5.uic' in packages:
+        if "PyQt5.uic" in packages:
             # ditto
             if sys.version_info[0] == 2:
-                ref = 'PyQt5.uic.port_v3'
+                ref = "PyQt5.uic.port_v3"
             else:
-                ref = 'PyQt5.uic.port_v2'
+                ref = "PyQt5.uic.port_v2"
 
             # Exclude...
             mf.lazynodes[ref] = None
@@ -107,48 +107,40 @@ class Sip(object):
             print("sip: No sip package used in application")
             return None
 
-        mf.import_hook('sip', m)
-        m = mf.findNode('sip')
+        mf.import_hook("sip", m)
+        m = mf.findNode("sip")
         # naive inclusion of ALL sip packages
         # stupid C modules.. hate hate hate
         for pkg in packages:
             try:
                 mf.import_hook(pkg, m)
             except ImportError as exc:
-                print("WARNING: ImportError in sip recipe ignored: %s" % (
-                    exc,))
+                print("WARNING: ImportError in sip recipe ignored: %s" % (exc,))
 
-        if mf.findNode('PyQt4') is not None \
-                or mf.findNode('PyQt5') is not None:
-            resources = [
-                pkg_resources.resource_filename('py2app', 'recipes/qt.conf')]
+        if mf.findNode("PyQt4") is not None or mf.findNode("PyQt5") is not None:
+            resources = [pkg_resources.resource_filename("py2app", "recipes/qt.conf")]
 
             for item in cmd.qt_plugins:
-                if '/' not in item:
-                    item = item + '/*'
+                if "/" not in item:
+                    item = item + "/*"
 
-                if '*' in item:
+                if "*" in item:
                     for path in glob.glob(os.path.join(self.plugin_dir, item)):
-                        rel_path = path[len(self.plugin_dir):]
+                        rel_path = path[len(self.plugin_dir) :]  # noqa: E203
                         resources.append(
-                            (
-                                os.path.dirname('qt_plugins' + rel_path),
-                                [path]
-                            )
+                            (os.path.dirname("qt_plugins" + rel_path), [path])
                         )
                 else:
                     resources.append(
                         (
-                            os.path.dirname(os.path.join('qt_plugins', item)),
-                            [os.path.join(self.plugin_dir, item)]
+                            os.path.dirname(os.path.join("qt_plugins", item)),
+                            [os.path.join(self.plugin_dir, item)],
                         )
                     )
 
-            print("PyQt resources", resources)
-            return dict(resources=resources)
+            return {"resources": resources}
 
-        print("Return {}")
-        return dict()
+        return {}
 
 
 check = Sip().check
